@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## A real Try Catch Block Implementation Using Perl Filter - ~/lib/Nice/Try.pm
-## Version v1.0.3
+## Version v1.0.4
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2020/05/17
-## Modified 2021/05/29
+## Modified 2021/05/31
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -23,7 +23,7 @@ BEGIN
     use Scalar::Util ();
     use List::Util ();
     use Want ();
-    our $VERSION = 'v1.0.3';
+    our $VERSION = 'v1.0.4';
     our $ERROR;
     our( $CATCH, $DIED, $EXCEPTION, $FINALLY, $HAS_CATCH, @RETVAL, $SENTINEL, $TRY, $WANTARRAY );
 }
@@ -623,7 +623,7 @@ EOT
             
             my $try_sub = <<EOT;
 CORE::local \$Nice::Try::THREADED;
-if( \$INC{'threads.pm'} )
+if( \$INC{'threads.pm'} && !CORE::exists( \$INC{'forks.pm'} ) )
 {
     \$Nice::Try::THREADED = threads->tid;
 }
@@ -1650,7 +1650,7 @@ Also since version 1.0.0, L<Nice::Try> is context aware:
 
 =head1 VERSION
 
-    v1.0.3
+    v1.0.4
 
 =head1 DESCRIPTION
 
@@ -1841,7 +1841,7 @@ For example L<TryCatch>
 
 =item 4 Others
 
-For example L<Syntax::Keyword::Try> and now perl with L<version 5.33.7 using experimental feature|https://perldoc.perl.org/blead/perlsyn#Try-Catch-Exception-Handling>.
+For example L<Syntax::Keyword::Try> and now perl with L<version 5.34.0 using experimental feature|https://perldoc.perl.org/5.34.0/perldelta#Experimental-Try/Catch-Syntax>.
 
 =back
 
@@ -1940,7 +1940,7 @@ That is because L<Syntax::Keyword::Try> expects to be C<used> outside of a BEGIN
 
 Of course, with L<Nice::Try>, there is no such constraint. You can L<perlfunc/use> L<Nice::Try> inside or outside of a C<BEGIN> block indistinctively.
 
-Since L<perl version 5.33.7|https://perldoc.perl.org/blead/perlsyn#Try-Catch-Exception-Handling> you can use the try-catch block using an experimental feature which may be removed in future versions, by writing:
+Since L<perl version 5.33.7|https://perldoc.perl.org/blead/perlsyn#Try-Catch-Exception-Handling> and now in L<perl v5.34.0|https://perldoc.perl.org/5.34.0/perldelta#Experimental-Try/Catch-Syntax> you can use the try-catch block using an experimental feature which may be removed in future versions, by writing:
 
     use feature 'try'; # will emit a warning this is experimental
 
@@ -1977,7 +1977,9 @@ Also, the C<use feature 'try'> expression must be in the relevant block where yo
 
 It is probably a matter of time until this is fully implemented in perl as a regular non-experimental feature.
 
-So, L<Nice::Try> is quite unique and fills the missing features, but because it is purely in perl and not an XS module, it is slower than XS module like L<Syntax::Keyword::Try>. I am not sure the difference would be that noticeable, since the parsing by L<PPI> is now done using an XS module, which makes things very fast.
+See more information about perl's featured implementation of try-catch in L<https://perldoc.perl.org/5.34.0/perlsyn#Try-Catch-Exception-Handling|perlsyn>
+
+So, L<Nice::Try> is quite unique and fills the missing features, and since it uses XS modules for a one-time filtering, it is quite fast.
 
 =head1 FINALLY
 
